@@ -37,6 +37,8 @@ localeDirectory = os.path.abspath(os.path.join(os.path.dirname( __file__ ), '..'
 
 # Create Handlers (Triggers) for each item
 class Handler:
+    with open(settingsFile) as outfile:
+        self.settings = json.load(outfile)
 
 # Close the window
     def onDestroy4(self, *args):
@@ -57,7 +59,7 @@ class Handler:
     def onDowngrade(self, button):
         print("Entered Text: ", enteredText)
         Notify.Notification.new("Downgrading...").show()
-        os.system('bash ' + bashFile + ' Downgrade ' + settingsFile + ' ' + enteredText)
+        os.system('bash ' + bashFile + ' Downgrade ' + enteredText + ' ' + self.settings["terminal"])
         Gtk.main_quit()
 
 ################################################################################
